==> intel_extension_for_tensorflow-2.14.0.2-cp310-cp310-manylinux_2_17_x86_64.manylinux2014_x86_64.whl: intel_extension_for_tensorflow/python/ops/__init__.py <==
# Copyright (c) 2023 Intel Corporation
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================

# pylint: disable=g-bad-import-order,unused-import,missing-module-docstring,unused-import,line-too-long
from intel_extension_for_tensorflow.python.ops.activations import gelu
from intel_extension_for_tensorflow.python.ops import ops_grad as _ops_grad
from intel_extension_for_tensorflow.python.ops.optimizers import AdamWithWeightDecayOptimizer
from intel_extension_for_tensorflow.python.ops.layer_norm import LayerNormalization
from intel_extension_for_tensorflow.python.ops.group_norm import GroupNormalization
from intel_extension_for_tensorflow.python.ops.rms_norm import RMSNormalization
from intel_extension_for_tensorflow.python.ops.recurrent import ItexLSTM
from intel_extension_for_tensorflow.python.ops.mlp import FusedDenseBiasAddGelu
from intel_extension_for_tensorflow.python.ops.multi_head_attention import scaled_dot_product_attention

==> intel_extension_for_tensorflow-2.15.0.0-cp310-cp310-manylinux_2_17_x86_64.manylinux2014_x86_64.whl: intel_extension_for_tensorflow/python/ops/__init__.py <==
# Copyright (c) 2023 Intel Corporation
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================

# pylint: disable=g-bad-import-order,unused-import,missing-module-docstring,unused-import,line-too-long
from intel_extension_for_tensorflow.python.ops.beam_select import beam_select_kv_cache
from intel_extension_for_tensorflow.python.ops.activations import gelu
from intel_extension_for_tensorflow.python.ops.rotary_embedding import qk_rotary_positional_embedding
from intel_extension_for_tensorflow.python.ops import ops_grad as _ops_grad
from intel_extension_for_tensorflow.python.ops.optimizers import AdamWithWeightDecayOptimizer, AdamWithWeightDecayLegacyOptimizer, LAMBOptimizer
from intel_extension_for_tensorflow.python.ops.layer_norm import LayerNormalization
from intel_extension_for_tensorflow.python.ops.group_norm import GroupNormalization
from intel_extension_for_tensorflow.python.ops.rms_norm import RMSNormalization
from intel_extension_for_tensorflow.python.ops.recurrent import ItexLSTM
from intel_extension_for_tensorflow.python.ops.mlp import FusedDenseBiasAddGelu
from intel_extension_for_tensorflow.python.ops.multi_head_attention import scaled_dot_product_attention
